@@ -1,6 +1,8 @@
 module.exports = {
     arrowParens: "avoid",
     trailingComma: "es5",
+    tabWidth: 4,
+    useTabs: false,
     overrides: [
         {
             files: "*.vue",
@@ -9,4 +11,4 @@ module.exports = {
             }
         }
     ]
-}
\ No newline at end of file
+}
