@@ -40,6 +40,7 @@ use Koha::Patrons;
 use Koha::SMS::Providers;
 use Koha::SMTP::Servers;
 use Koha::Subscriptions;
+use Koha::Template::Plugin::KohaDates;
 
 use constant SERIALIZED_EMAIL_CONTENT_TYPE => 'message/rfc822';
 
@@ -307,7 +308,7 @@ sub SendAlerts {
         my $subscription = Koha::Subscriptions->find( $subscriptionid );
         my $subscribers = $subscription->subscribers;
         while ( my $patron = $subscribers->next ) {
-            my $email = $patron->email or next;
+            my $email = $patron->notice_email_address or next;
 
 #                    warn "sending issues...";
             my $userenv = C4::Context->userenv;
@@ -625,6 +626,10 @@ sub GetPreparedLetter {
       or carp( "ERROR: nothing to substitute - all of 'objects', 'tables', 'loops' and 'substitute' are empty" ),
          return;
     my $want_librarian = $params{want_librarian};
+    if ($want_librarian) {
+        my $userenv = C4::Context->userenv;
+        $objects->{librarian} = Koha::Patrons->find( C4::Context->userenv->{number} ) if ($userenv);
+    }
 
     # Best guess at language 'default' notice is written for include handling
     if ( $lang eq 'default' ) {
@@ -634,6 +639,10 @@ sub GetPreparedLetter {
         $lang = shift @languages;
     }
 
+    $Template::Stash::SCALAR_OPS->{strftime} = sub {
+        return Koha::Template::Plugin::KohaDates->strftime(@_);
+    };
+
     $letter->{content} = _process_tt(
         {
             content    => $letter->{content},
@@ -958,6 +967,12 @@ sub EnqueueLetter {
         );
     }
 
+    if ( $params->{message_transport_type} eq 'sms' ) {
+        my $limit = C4::Context->preference('SMSSendMaxChar');
+        $params->{letter}->{content} = substr( $params->{letter}->{content}, 0, $limit - 3 ) . '...'
+            if ( $limit && length( $params->{letter}->{content} ) > $limit );
+    }
+
     my $message = Koha::Notice::Message->new(
         {
             letter_id              => $params->{letter}->{id} || undef,
@@ -1011,6 +1026,23 @@ sub SendQueuedMessages {
     Koha::Exceptions::BadParameter->throw("Parameter message_id cannot be empty if passed.")
         if ( exists( $params->{message_id} ) && !$params->{message_id} );
 
+    if ( C4::Context->config("enable_plugins") ) {
+        my @plugins = Koha::Plugins->new->GetPlugins({
+            method => 'before_send_messages',
+        });
+
+        if (@plugins) {
+            foreach my $plugin (@plugins) {
+                try {
+                    $plugin->before_send_messages($params);
+                } catch {
+                    warn "$_";
+                    exit 1 if $params->{exit_on_plugin_failure};
+                };
+            }
+        }
+    }
+
     my $smtp_transports = {};
 
     my $count_messages = 0;
