@@ -6,19 +6,25 @@ package C4::SIP::ILS;
 
 use warnings;
 use strict;
-use C4::SIP::Sip qw( siplog );
-use Koha::DateUtils qw( dt_from_string output_pref );
-use Data::Dumper;
 
+use C4::Context;
 use C4::SIP::ILS::Item;
 use C4::SIP::ILS::Patron;
-use C4::SIP::ILS::Transaction;
-use C4::SIP::ILS::Transaction::Checkout;
 use C4::SIP::ILS::Transaction::Checkin;
+use C4::SIP::ILS::Transaction::Checkout;
 use C4::SIP::ILS::Transaction::FeePayment;
 use C4::SIP::ILS::Transaction::Hold;
 use C4::SIP::ILS::Transaction::Renew;
 use C4::SIP::ILS::Transaction::RenewAll;
+use C4::SIP::ILS::Transaction;
+use C4::SIP::Sip qw( siplog );
+
+use Koha::Account;
+use Koha::Account::Lines;
+use Koha::DateUtils qw( dt_from_string output_pref );
+use Koha::Items;
+use Koha::Libraries;
+use Koha::Number::Price;
 
 my %supports = (
     'magnetic media'        => 1,
@@ -181,11 +187,11 @@ sub checkout {
             $circ->screen_msg("Patron blocked");
         }
     }
-    elsif ( !$item ) {
-        $circ->screen_msg("Invalid Item");
-    }
-    elsif ( $item->{borrowernumber}
-        && !_ci_cardnumber_cmp( $item->{borrowernumber}, $patron->borrowernumber ) )
+    elsif (
+        $item->{borrowernumber}
+            && !C4::Context->preference('AllowItemsOnLoanCheckoutSIP')
+            && !_ci_cardnumber_cmp( $item->{borrowernumber}, $patron->borrowernumber )
+        )
     {
         $circ->screen_msg("Item checked out to another patron");
     }
