@@ -216,6 +216,12 @@ our $RULE_KINDS = {
     holds_pickup_period => {
         scope => [ 'branchcode', 'categorycode', 'itemtype' ],
     },
+    bookings_lead_period => {
+        scope => [ 'branchcode', 'itemtype' ],
+    },
+    bookings_trail_period => {
+        scope => [ 'branchcode', 'itemtype' ],
+    },
     # Not included (deprecated?):
     #   * accountsent
     #   * reservecharge
