@@ -847,6 +847,7 @@ sub fill {
                 {
                     found    => 'F',
                     priority => 0,
+                    timestamp => dt_from_string->strftime( '%Y-%m-%d %H:%M:%S' ),
                     $params->{item_id} ? ( itemnumber => $params->{item_id} ) : (),
                 }
             );
@@ -986,6 +987,9 @@ sub store {
                 }
             }
         }
+        if ( exists $updated_columns{branchcode} ) {
+            Koha::BackgroundJob::BatchUpdateBiblioHoldsQueue->new->enqueue( { biblio_ids => [ $self->biblionumber ] } );
+        }
     }
 
     $self = $self->SUPER::store;
@@ -1076,10 +1080,34 @@ Returns a map of column name to string representations including the string.
 =cut
 
 sub strings_map {
-    my ($self) = @_;
-    return {
-        pickup_library_id => { str => $self->branch->branchname, type => 'library' },
+    my ( $self, $params ) = @_;
+
+    my $strings = {
+        pickup_library_id => { str => $self->pickup_library->branchname, type => 'library' },
     };
+
+    if ( defined $self->cancellation_reason ) {
+        my $av = Koha::AuthorisedValues->search(
+            {
+                category         => 'HOLD_CANCELLATION',
+                authorised_value => $self->cancellation_reason,
+            }
+        );
+        my $cancellation_reason_str =
+              $av->count
+            ? $params->{public}
+                ? $av->next->opac_description
+                : $av->next->lib
+            : $self->cancellation_reason;
+
+        $strings->{cancellation_reason} = {
+            category => 'HOLD_CANCELLATION',
+            str      => $cancellation_reason_str,
+            type     => 'av',
+        };
+    }
+
+    return $strings;
 }
 
 =head2 Internal methods
