@@ -19,29 +19,32 @@ package Koha::ILL::Request;
 
 use Modern::Perl;
 
-use Clone qw( clone );
-use Try::Tiny qw( catch try );
+use Clone     qw(clone);
+use Try::Tiny qw(catch try);
 use DateTime;
 
 use C4::Letters;
-use Mojo::Util qw(deprecated);
+use Mojo::Util     qw(deprecated);
+use File::Basename qw(dirname);
 
+use Koha::AuthorisedValue;
+use Koha::AuthorisedValues;
+use Koha::Biblios;
 use Koha::Cache::Memory::Lite;
 use Koha::Database;
 use Koha::DateUtils qw( dt_from_string );
 use Koha::Exceptions::Ill;
+use Koha::I18N qw(__);
+use Koha::ILL::Backend::Standard;
+use Koha::ILL::Batches;
 use Koha::ILL::Comments;
 use Koha::ILL::Request::Attributes;
-use Koha::AuthorisedValue;
 use Koha::ILL::Request::Logger;
-use Koha::Patron;
-use Koha::ILL::Batches;
-use Koha::AuthorisedValues;
-use Koha::Biblios;
-use Koha::Items;
 use Koha::ItemTypes;
+use Koha::Items;
 use Koha::Libraries;
 use Koha::AdditionalContents;
+use Koha::Patron;
 
 use C4::Circulation qw( CanBookBeIssued AddIssue );
 
@@ -274,12 +277,42 @@ sub library {
 
     my $extended_attributes = $request->extended_attributes;
 
-Returns the linked I<Koha::ILL::Request::Attributes> resultset object.
+    my $extended_attributes = $request->extended_attributes([
+        {
+            type => 'type',
+            value => 'type_value',
+        },
+        {
+            type => 'type2',
+            value => 'type2_value',
+        },
+    ]);
+
+Getter or setter for extended attributes
+
+Getter: Returns the linked I <Koha::ILL::Request::Attributes> resultset object.
+
+Setter: Adds the supplied extended attributes to the request
 
 =cut
 
 sub extended_attributes {
-    my ( $self ) = @_;
+    my ( $self, $attributes ) = @_;
+
+    if ($attributes) {
+        my $schema = $self->_result->result_source->schema;
+        $schema->txn_do(
+            sub {
+                for my $attribute (@$attributes) {
+                    $attribute->{backend} = $self->backend;
+                    eval { $self->_result->add_to_illrequestattributes($attribute); };
+                    if ($@) {
+                        warn "Error adding attribute $attribute->{type}: $@";
+                    }
+                }
+            }
+        );
+    }
 
     my $rs = $self->_result->extended_attributes;
     # We call search to use the filters in Koha::ILL::Request::Attributes->search
@@ -438,16 +471,21 @@ sub load_backend {
             "An invalid backend ID was requested ('')");
     }
 
+    my $backend_params = {
+        config => $self->_config,
+        logger => Koha::ILL::Request::Logger->new
+    };
+
     # Find plugin implementing the backend for the request
     my $backend_plugin = $self->get_backend_plugin($backend_name);
-    if ($backend_plugin) {
 
-        $self->{_my_backend} = $backend_plugin->new_ill_backend(
-            {
-                config => $self->_config,
-                logger => Koha::ILL::Request::Logger->new
-            }
-        );
+    if ( $backend_name eq 'Standard' ) {
+
+        # Load the Standard core backend
+        $self->{_my_backend} = Koha::ILL::Backend::Standard->new($backend_params);
+    } elsif ($backend_plugin) {
+
+        $self->{_my_backend} = $backend_plugin->new_ill_backend($backend_params);
     } elsif ($backend_name) {
 
         # Fallback to loading through backend_dir config
@@ -455,12 +493,7 @@ sub load_backend {
         my $location      = join "/",  @raw, $backend_name, "Base.pm";    # File to load
         my $backend_class = join "::", @raw, $backend_name, "Base";       # Package name
         require $location;
-        $self->{_my_backend} = $backend_class->new(
-            {
-                config => $self->_config,
-                logger => Koha::ILL::Request::Logger->new
-            }
-        );
+        $self->{_my_backend} = $backend_class->new($backend_params);
     }
 
     return $self;
@@ -578,8 +611,8 @@ sub _core_status_graph {
             prev_actions => [ ],                           # Actions containing buttons
                                                            # leading to this status
             id             => 'NEW',                       # ID of this status
-            name           => 'New request',               # UI name of this status
-            ui_method_name => 'New request',               # UI name of method leading
+            name           => __('New request'),           # UI name of this status
+            ui_method_name => __('New request'),           # UI name of method leading
                                                            # to this status
             method         => 'create',                    # method to this status
             next_actions   => [ 'REQ', 'GENREQ', 'KILL' ], # buttons to add to all
@@ -589,8 +622,8 @@ sub _core_status_graph {
         REQ => {
             prev_actions   => [ 'NEW', 'REQREV', 'QUEUED', 'CANCREQ' ],
             id             => 'REQ',
-            name           => 'Requested',
-            ui_method_name => 'Confirm request',
+            name           => __('Requested'),
+            ui_method_name => __('Confirm request'),
             method         => 'confirm',
             next_actions   => [ 'REQREV', 'COMP', 'CHK' ],
             ui_method_icon => 'fa-check',
@@ -598,8 +631,8 @@ sub _core_status_graph {
         GENREQ => {
             prev_actions   => [ 'NEW', 'REQREV' ],
             id             => 'GENREQ',
-            name           => 'Requested from partners',
-            ui_method_name => 'Place request with partners',
+            name           => __('Requested from partners'),
+            ui_method_name => __('Place request with partners'),
             method         => 'generic_confirm',
             next_actions   => [ 'COMP', 'CHK', 'REQREV' ],
             ui_method_icon => 'fa-paper-plane',
@@ -607,8 +640,8 @@ sub _core_status_graph {
         REQREV => {
             prev_actions   => [ 'REQ', 'GENREQ' ],
             id             => 'REQREV',
-            name           => 'Request reverted',
-            ui_method_name => 'Revert request',
+            name           => __('Request reverted'),
+            ui_method_name => __('Revert request'),
             method         => 'cancel',
             next_actions   => [ 'REQ', 'GENREQ', 'KILL' ],
             ui_method_icon => 'fa-times',
@@ -616,7 +649,7 @@ sub _core_status_graph {
         QUEUED => {
             prev_actions   => [ ],
             id             => 'QUEUED',
-            name           => 'Queued request',
+            name           => __('Queued request'),
             ui_method_name => 0,
             method         => 0,
             next_actions   => [ 'REQ', 'KILL' ],
@@ -625,7 +658,7 @@ sub _core_status_graph {
         CANCREQ => {
             prev_actions   => [ 'NEW' ],
             id             => 'CANCREQ',
-            name           => 'Cancellation requested',
+            name           => __('Cancellation requested'),
             ui_method_name => 0,
             method         => 0,
             next_actions   => [ 'KILL', 'REQ' ],
@@ -634,8 +667,8 @@ sub _core_status_graph {
         COMP => {
             prev_actions   => [ 'REQ' ],
             id             => 'COMP',
-            name           => 'Completed',
-            ui_method_name => 'Mark completed',
+            name           => __('Completed'),
+            ui_method_name => __('Mark completed'),
             method         => 'mark_completed',
             next_actions   => [ 'CHK' ],
             ui_method_icon => 'fa-check',
@@ -644,7 +677,7 @@ sub _core_status_graph {
             prev_actions   => [ 'QUEUED', 'REQREV', 'NEW', 'CANCREQ' ],
             id             => 'KILL',
             name           => 0,
-            ui_method_name => 'Delete request',
+            ui_method_name => __('Delete request'),
             method         => 'delete',
             next_actions   => [ ],
             ui_method_icon => 'fa-trash',
@@ -652,8 +685,8 @@ sub _core_status_graph {
         CHK => {
             prev_actions   => [ 'REQ', 'GENREQ', 'COMP' ],
             id             => 'CHK',
-            name           => 'Checked out',
-            ui_method_name => 'Check out',
+            name           => __('Checked out'),
+            ui_method_name => __('Check out'),
             needs_prefs    => [ 'CirculateILL' ],
             needs_perms    => [ 'user_circulate_circulate_remaining_permissions' ],
             # An array of functions that all must return true
@@ -665,8 +698,8 @@ sub _core_status_graph {
         RET => {
             prev_actions   => [ 'CHK' ],
             id             => 'RET',
-            name           => 'Returned to library',
-            ui_method_name => 'Check in',
+            name           => __('Returned to library'),
+            ui_method_name => __('Check in'),
             method         => 'check_in',
             next_actions   => [ 'COMP' ],
             ui_method_icon => 'fa-download',
@@ -1101,6 +1134,11 @@ sub expand_template {
         # New way of loading backends: Through plugins
         $backend_dir  = $backend_plugin->bundle_path;
         $backend_tmpl = $backend_dir;
+
+    } elsif ( $backend eq 'Standard' ) {
+
+        # Check for core Standard backend
+        $backend_tmpl = dirname(__FILE__) . '/Backend';
     } else {
 
         # Old way of loading backends: Through backend_dir config
@@ -1831,7 +1869,7 @@ sub get_notice {
         letter_code            => $params->{notice_code},
         branchcode             => $self->branchcode,
         message_transport_type => $params->{transport},
-        lang                   => $self->patron->lang,
+        lang                   => $self->patron ? $self->patron->lang : undef,
         tables                 => {
             illrequests => $self->illrequest_id,
             borrowers   => $self->borrowernumber,
@@ -2111,6 +2149,32 @@ sub strings_map {
     return $strings;
 }
 
+=head3 can_patron_place_ill_in_opac
+
+    my $can_patron_place_ill_in_opac = Koha::Illrequest->can_patron_place_ill_in_opac($patron);
+
+Returns whether the given patron can place an ILL request in OPAC
+
+=over
+
+=item patron
+
+Patron object
+
+=back
+
+=cut
+
+sub can_patron_place_ill_in_opac {
+    my ( $self, $patron ) = @_;
+
+    return 0
+        unless $patron->_result->categorycode->can_place_ill_in_opac
+        && !( $patron->is_expired
+        && $patron->category->effective_BlockExpiredPatronOpacActions_contains('ill_request') );
+    return 1;
+}
+
 =head3 get_op_param_deprecation
 
     my $op = $req->check_url_param_deprecation($params);
