@@ -22,7 +22,6 @@ use Mojo::Base 'Mojolicious::Controller';
 use Koha::Biblios;
 use Koha::DateUtils;
 use Koha::Ratings;
-use Koha::RecordProcessor;
 use C4::Biblio qw( DelBiblio AddBiblio ModBiblio );
 use C4::Search qw( FindDuplicate );
 
@@ -162,32 +161,19 @@ sub get_public {
 
     return try {
 
-        my $metadata = $biblio->metadata;
-        my $record   = $metadata->record;
-
-        my $opachiddenitems_rules = C4::Context->yaml_preference('OpacHiddenItems');
+        my $schema = $biblio->metadata->schema // C4::Context->preference("marcflavour");
         my $patron = $c->stash('koha.user');
 
-        # Check if the biblio should be hidden for unprivileged access
-        # unless there's a logged in user, and there's an exception for it's
-        # category
+        # Check if the bibliographic record should be hidden for unprivileged access
+        # unless there's a logged in user, and there's an exception for it's category
+        my $opachiddenitems_rules = C4::Context->yaml_preference('OpacHiddenItems');
         unless ( $patron and $patron->category->override_hidden_items ) {
             if ( $biblio->hidden_in_opac( { rules => $opachiddenitems_rules } ) ) {
                 return $c->render_resource_not_found("Bibliographic record");
             }
         }
 
-        my $schema = $metadata->schema // C4::Context->preference("marcflavour");
-
-        my $record_processor = Koha::RecordProcessor->new({
-            filters => 'ViewPolicy',
-            options => {
-                interface => 'opac',
-                frameworkcode => $biblio->frameworkcode
-            }
-        });
-        # Apply framework's filtering to MARC::Record object
-        $record_processor->process($record);
+        my $record = $biblio->metadata_record( { interface => 'opac', patron => $patron } );
 
         $c->respond_to(
             marcxml => {
@@ -266,6 +252,9 @@ sub get_items {
     my $biblio        = Koha::Biblios->find( { biblionumber => $c->param('biblio_id') }, { prefetch => ['items'] } );
     my $bookable_only = $c->param('bookable');
 
+    # Deletion of parameter to avoid filtering on the items table in the case of bookings on 'itemtype'
+    $c->req->params->remove('bookable');
+
     return $c->render_resource_not_found("Bibliographic record")
         unless $biblio;
 
@@ -381,6 +370,10 @@ sub add_item {
 
         $item->store->discard_changes;
 
+        my $base_url = $c->req->url->to_string;
+        $base_url =~ s|/biblios/\d+||;
+        $c->res->headers->location( $base_url . '/' . $item->id );
+
         $c->render(
             status  => 201,
             openapi => $c->objects->to_api($item),
@@ -702,21 +695,37 @@ sub add {
             );
         }
 
-        my ( $duplicatebiblionumber, $duplicatetitle );
-            ( $duplicatebiblionumber, $duplicatetitle ) = FindDuplicate($record);
-
         my $confirm_not_duplicate = $headers->header('x-confirm-not-duplicate');
 
+        if ( !$confirm_not_duplicate ) {
+            my ( $duplicatebiblionumber, $duplicatetitle ) = FindDuplicate($record);
+
+            return $c->render(
+                status  => 400,
+                openapi => {
+                    error => "Duplicate biblio $duplicatebiblionumber",
+                }
+            ) if $duplicatebiblionumber;
+        }
+
+        my ($biblio_id) = C4::Biblio::AddBiblio( $record, $frameworkcode, { record_source_id => $record_source_id } );
+
+        if ( !$biblio_id ) {
+
+            # FIXME: AddBiblio wraps everything inside a transaction and a try/catch block
+            # this will need a tweak if this behavior changes
+            return $c->render(
+                status  => 400,
+                openapi => {
+                    error      => 'Error creating record',
+                    error_code => 'record_creation_failed',
+                },
+            );
+        }
+
+        $c->res->headers->location( $c->req->url->to_string . '/' . $biblio_id );
+
         return $c->render(
-            status  => 400,
-            openapi => {
-                error => "Duplicate biblio $duplicatebiblionumber",
-            }
-        ) unless !$duplicatebiblionumber || $confirm_not_duplicate;
-
-        my ( $biblio_id ) = AddBiblio( $record, $frameworkcode, { record_source_id => $record_source_id } );
-
-        $c->render(
             status  => 200,
             openapi => { id => $biblio_id }
         );
