@@ -85,13 +85,18 @@ sub add {
 
                 my $body = $c->req->json;
 
-                my $user_roles = delete $body->{user_roles} // [];
-                my $documents = delete $body->{documents} // [];
+                my $user_roles          = delete $body->{user_roles}          // [];
+                my $documents           = delete $body->{documents}           // [];
+                my $extended_attributes = delete $body->{extended_attributes} // [];
 
                 my $license = Koha::ERM::License->new_from_api($body)->store;
                 $license->user_roles($user_roles);
                 $license->documents($documents);
 
+                my @extended_attributes =
+                    map { { 'id' => $_->{field_id}, 'value' => $_->{value} } } @{$extended_attributes};
+                $license->extended_attributes( \@extended_attributes );
+
                 $c->res->headers->location($c->req->url->to_string . '/' . $license->license_id);
                 return $c->render(
                     status  => 201,
@@ -163,13 +168,18 @@ sub update {
 
                 my $body = $c->req->json;
 
-                my $user_roles = delete $body->{user_roles} // [];
-                my $documents = delete $body->{documents} // [];
+                my $user_roles          = delete $body->{user_roles}          // [];
+                my $documents           = delete $body->{documents}           // [];
+                my $extended_attributes = delete $body->{extended_attributes} // [];
 
                 $license->set_from_api($body)->store;
                 $license->user_roles($user_roles);
                 $license->documents($documents);
 
+                my @extended_attributes =
+                    map { { 'id' => $_->{field_id}, 'value' => $_->{value} } } @{$extended_attributes};
+                $license->extended_attributes( \@extended_attributes );
+
                 $c->res->headers->location($c->req->url->to_string . '/' . $license->license_id);
                 return $c->render(
                     status  => 200,
