@@ -292,6 +292,7 @@ sub bundled_items {
     };
 }
 
+
 =head3 add_to_bundle
 
 Controller function that handles adding items to this bundle
@@ -302,7 +303,7 @@ sub add_to_bundle {
     my $c = shift->openapi->valid_input or return;
 
     my $item_id = $c->param('item_id');
-    my $item = Koha::Items->find( $item_id );
+    my $item    = Koha::Items->find($item_id);
 
     return $c->render_resource_not_found("Item")
         unless $item;
@@ -316,19 +317,22 @@ sub add_to_bundle {
     return $c->render_resource_not_found("Bundle item")
         unless $bundle_item;
 
+    my $add_link = $body->{'marc_link'} // 0;
     return try {
         my $options = {
             force_checkin => $body->{force_checkin},
-            ignore_holds => $body->{ignore_holds},
+            ignore_holds  => $body->{ignore_holds},
         };
 
-        my $link = $item->add_to_bundle($bundle_item, $options);
+        my $link = $item->add_to_bundle( $bundle_item, $options );
+        if ($add_link) {
+            $bundle_item->biblio->link_marc_host( { host => $item->biblio } );
+        }
         return $c->render(
             status  => 201,
-            openapi => $bundle_item
+            openapi => $bundle_item->to_api
         );
-    }
-    catch {
+    } catch {
         if ( ref($_) eq 'Koha::Exceptions::Object::DuplicateID' ) {
             return $c->render(
                 status  => 409,
@@ -338,8 +342,7 @@ sub add_to_bundle {
                     key        => $_->duplicate_id
                 }
             );
-        }
-        elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::BundleIsCheckedOut' ) {
+        } elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::BundleIsCheckedOut' ) {
             return $c->render(
                 status  => 409,
                 openapi => {
@@ -355,8 +358,7 @@ sub add_to_bundle {
                     error_code => 'checked_out'
                 }
             );
-        }
-        elsif ( ref($_) eq 'Koha::Exceptions::Checkin::FailedCheckin' ) {
+        } elsif ( ref($_) eq 'Koha::Exceptions::Checkin::FailedCheckin' ) {
             return $c->render(
                 status  => 409,
                 openapi => {
@@ -364,8 +366,7 @@ sub add_to_bundle {
                     error_code => 'failed_checkin'
                 }
             );
-        }
-        elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::ItemHasHolds' ) {
+        } elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::ItemHasHolds' ) {
             return $c->render(
                 status  => 409,
                 openapi => {
@@ -373,8 +374,7 @@ sub add_to_bundle {
                     error_code => 'reserved'
                 }
             );
-        }
-        elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::IsBundle' ) {
+        } elsif ( ref($_) eq 'Koha::Exceptions::Item::Bundle::IsBundle' ) {
             return $c->render(
                 status  => 400,
                 openapi => {
@@ -382,8 +382,7 @@ sub add_to_bundle {
                     error_code => 'failed_nesting'
                 }
             );
-        }
-        else {
+        } else {
             $c->unhandled_exception($_);
         }
     };
@@ -408,12 +407,8 @@ sub remove_from_bundle {
     $bundle_item_id = barcodedecode($bundle_item_id);
     my $bundle_item = Koha::Items->find( { itemnumber => $bundle_item_id } );
 
-    unless ($bundle_item) {
-        return $c->render(
-            status  => 404,
-            openapi => { error => "Bundle item not found" }
-        );
-    }
+    return $c->render_resource_not_found("Bundle item")
+        unless $bundle_item;
 
     return try {
         $bundle_item->remove_from_bundle;
