@@ -16,6 +16,8 @@ package Koha::UI::Form::Builder::Biblio;
 # along with Koha; if not, see <http://www.gnu.org/licenses>.
 
 use Modern::Perl;
+use feature qw(fc);
+
 use C4::Context;
 use C4::ClassSource qw( GetClassSources );
 use Koha::DateUtils qw( dt_from_string );
@@ -50,8 +52,11 @@ sub new {
 
     my $self = {};
 
-    $self->{biblionumber} = $params->{biblionumber} =~ s/\D//gr;
-    # just in case biblionumber obtained from CGI and passed directly here contains weird characters like spaces
+    if ( defined $params->{biblionumber} ) {
+        $self->{biblionumber} = $params->{biblionumber} =~ s/\D//gr;
+
+        # just in case biblionumber obtained from CGI and passed directly here contains weird characters like spaces
+    }
 
     bless $self, $class;
     return $self;
@@ -330,7 +335,7 @@ sub build_authorized_values_list {
 
         my $default_source = C4::Context->preference("DefaultClassificationSource");
 
-        foreach my $class_source (sort keys %$class_sources) {
+        foreach my $class_source (sort {fc($a) cmp fc($b)} keys %$class_sources) {
             next unless $class_sources->{$class_source}->{'used'} or
                         ($value and $class_source eq $value) or
                         ($class_source eq $default_source);
