@@ -117,17 +117,17 @@ if it is an order from an existing suggestion : the id of this suggestion.
 =cut
 
 use Modern::Perl;
-use CGI qw ( -utf8 );
+use CGI  qw ( -utf8 );
 use JSON qw ( to_json encode_json );
 
 use C4::Acquisition qw( FillWithDefaultValues ModOrderUsers );
-use C4::Auth qw( get_template_and_user );
+use C4::Auth        qw( get_template_and_user );
 use C4::Barcodes;
-use C4::Biblio qw( AddBiblio GetMarcFromKohaField TransformHtmlToXml TransformKohaToMarc );
-use C4::Budgets qw( GetBudget GetBudgetSpent GetBudgetOrdered FieldsForCalculatingFundValues );
-use C4::Items qw( AddItemFromMarc );
-use C4::Log qw( logaction );
-use C4::Output qw( output_html_with_http_headers );
+use C4::Biblio      qw( AddBiblio GetMarcFromKohaField TransformHtmlToXml TransformKohaToMarc );
+use C4::Budgets     qw( GetBudget GetBudgetSpent GetBudgetOrdered FieldsForCalculatingFundValues );
+use C4::Items       qw( AddItemFromMarc );
+use C4::Log         qw( logaction );
+use C4::Output      qw( output_html_with_http_headers );
 use C4::Suggestions qw( ModSuggestion );
 use Koha::Acquisition::Baskets;
 use Koha::Acquisition::Currencies qw( get_active );
@@ -386,18 +386,8 @@ if ( $op eq 'cud-order' ) {
         my @order_users     = split( /:/, $order_users_ids );
         ModOrderUsers( $order->ordernumber, @order_users );
 
-        # Retrieve and save additional fields values
-        my @additional_fields = Koha::AdditionalFields->search( { tablename => 'aqorders' } )->as_list;
-        my @additional_field_values;
-        foreach my $af (@additional_fields) {
-            my $id    = $af->id;
-            my $value = $input->param("additional_field_$id");
-            push @additional_field_values, {
-                id    => $id,
-                value => $value,
-            };
-        }
-        $order->set_additional_fields( \@additional_field_values );
+        my @additional_fields = $order->prepare_cgi_additional_field_values( $input, 'aqorders' );
+        $order->set_additional_fields( \@additional_fields );
 
         # now, add items if applicable
         if ( $basket->effective_create_items eq 'ordering' ) {
@@ -482,4 +472,3 @@ if ( $op eq 'cud-order' ) {
     print $input->redirect("/cgi-bin/koha/acqui/basket.pl?basketno=$basketno");
     exit;
 }
-
