@@ -94,7 +94,17 @@ my $bookseller = Koha::Acquisition::Booksellers->find( $booksellerid );
 my $schema = Koha::Database->new()->schema();
 my $rs = $schema->resultset('VendorEdiAccount')->search(
     { vendor_id => $booksellerid, } );
-$template->param( ediaccount => ($rs->count > 0));
+my $ediaccount = ( $rs->count > 0 );
+$template->param( ediaccount => $ediaccount );
+if ($ediaccount) {
+    my @eans = $schema->resultset('EdifactEan')->search(
+        {},
+        {
+            join => 'branch',
+        }
+    );
+    $template->param( eans => \@eans );
+}
 
 unless (CanUserManageBasket($loggedinuser, $basket, $userflags)) {
     $template->param(
@@ -242,6 +252,7 @@ if ( $op eq 'cud-delete-order' ) {
     print $query->redirect('/cgi-bin/koha/acqui/basket.pl?basketno='.$basket->{'basketno'})
 }
 elsif ( $op eq 'cud-ediorder' ) {
+    $template->param( booksellername => $bookseller->name );
     edi_close_and_order()
 } elsif ( $op eq 'cud-mod_users' ) {
     my $basketusers_ids = $query->param('users_ids');
@@ -442,9 +453,8 @@ if ( $op eq 'list' ) {
         duplinbatch          => $duplinbatch,
         csv_profiles         => Koha::CsvProfiles->search({ type => 'sql', used_for => 'export_basket' }),
         available_additional_fields => Koha::AdditionalFields->search( { tablename => 'aqbasket' } ),
-        additional_field_values => { map {
-            $_->field->name => $_->value
-        } Koha::Acquisition::Baskets->find($basketno)->additional_field_values->as_list },
+        additional_field_values =>
+            Koha::Acquisition::Baskets->find($basketno)->get_additional_field_values_for_template,
     );
 }
 
@@ -594,16 +604,20 @@ sub edi_close_and_order {
         exit;
     }
     else {
+
+        my $ean_description = $query->param('ean_description');
+        my $ean_branch      = $query->param('ean_branch');
+
         $template->param(
             edi_confirm     => 1,
             booksellerid    => $booksellerid,
             basketno        => $basket->{basketno},
             basketname      => $basket->{basketname},
             basketgroupname => $basket->{basketname},
+            ean             => $ean             ? $ean             : '',
+            ean_description => $ean_description ? $ean_description : '',
+            ean_branch      => $ean_branch      ? $ean_branch      : '',
         );
-        if ($ean) {
-            $template->param( ean => $ean );
-        }
 
     }
     return;
