@@ -33,8 +33,6 @@ use Koha::AuthorisedValues;
 use Koha::Libraries;
 use Koha::Patron::Categories;
 
-my $script_name = "/cgi-bin/koha/admin/patron-attr-types.pl";
-
 our $input = CGI->new;
 my $op = $input->param('op') || '';
 
@@ -47,9 +45,6 @@ my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     }
 );
 
-
-$template->param(script_name => $script_name);
-
 my $code = $input->param("code");
 
 my $display_list = 0;
