@@ -39,7 +39,7 @@ my $itemnotes_nonpublic=$cgi->param('itemnotes_nonpublic');
 my $withdrawn=$cgi->param('withdrawn');
 my $damaged=$cgi->param('damaged');
 my $exclude_from_local_holds_priority = $cgi->param('exclude_from_local_holds_priority');
-my $bookable = $cgi->param('bookable');
+my $bookable = $cgi->param('bookable') // q{};
 
 my $confirm=$cgi->param('confirm');
 my $dbh = C4::Context->dbh;
@@ -77,6 +77,7 @@ elsif ( $op eq "cud-set_public_note" ) { # i.e., itemnotes parameter passed from
     $item->exclude_from_local_holds_priority($exclude_from_local_holds_priority);
     $messages = "updated_exclude_from_local_holds_priority=$exclude_from_local_holds_priority&";
 } elsif ( $op eq "cud-set_bookable" && $bookable ne $item_data_hashref->{'bookable'} ) {
+    undef $bookable if $bookable eq q{};
     $item->bookable($bookable);
 } elsif ( $op eq "cud-set_damaged" && $damaged ne $item_data_hashref->{'damaged'}) {
     $item->damaged($damaged);
