@@ -144,21 +144,18 @@ my $display_order          = $input->param('item_group_display_order');
 our $frameworkcode = &GetFrameworkCode($biblionumber);
 
 # Defining which userflag is needing according to the framework currently used
-my $userflags;
-if ( defined $input->param('frameworkcode') ) {
-    $userflags = ( $input->param('frameworkcode') eq 'FA' ) ? "fast_cataloging" : "edit_items";
-}
-
-if ( not defined $userflags ) {
-    $userflags = ( $frameworkcode eq 'FA' ) ? "fast_cataloging" : "edit_items";
-}
+my $fast_cataloging_mode =
+    defined $input->param('frameworkcode')
+    ? $input->param('frameworkcode') eq 'FA'
+    : $frameworkcode eq 'FA';
 
 my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
     {
         template_name => "cataloguing/additem.tt",
         query         => $input,
         type          => "intranet",
-        flagsrequired => { editcatalogue => $userflags },
+        flagsrequired =>
+            { editcatalogue => $fast_cataloging_mode ? [ 'fast_cataloging', 'edit_items' ] : 'edit_items' },
     }
 );
 
