@@ -29,7 +29,7 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    ( 3, 'manage_item_search_fields', 'Manage item search fields'),
    ( 3, 'manage_search_engine_config', 'Manage search engine configuration'),
    ( 3, 'manage_marc_overlay_rules', 'Manage MARC overlay rules configuration'),
-   ( 3, 'manage_search_targets', 'Manage Z39.50 and SRU server configuration'),
+   ( 3, 'manage_search_targets', 'Manage Z39.50 and SRU servers, OAI repositories configuration'),
    ( 3, 'manage_didyoumean', 'Manage Did you mean? configuration'),
    ( 3, 'manage_column_config', 'Manage column configuration'),
    ( 3, 'manage_sms_providers', 'Manage SMS cellular providers'),
@@ -47,7 +47,6 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    ( 4, 'delete_borrowers', 'Delete patrons'),
    ( 4, 'edit_borrowers', 'Add, modify and view patron information'),
    ( 4, 'list_borrowers', 'Search, list and view patrons'),
-   ( 4, 'merge_borrowers', 'Merge patrons'),
    ( 4, 'send_messages_to_borrowers', 'Send messages to patrons'),
    ( 4, 'view_borrower_infos_from_any_libraries', 'View patron infos from any libraries'),
    ( 6, 'place_holds', 'Place holds for patrons'),
@@ -87,12 +86,15 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    (11, 'budget_add_del', 'Add and delete funds (but can''t modify funds)'),
    (11, 'budget_manage_all', 'Manage all funds'),
    (11, 'edi_manage', 'Manage EDIFACT transmissions'),
+   (11, 'marc_order_manage', 'Manage MARC ordering'),
    (11, 'reopen_closed_invoices', 'Reopen closed invoices'),
    (11, 'edit_invoices', 'Edit invoices'),
    (11, 'delete_invoices', 'Delete invoices'),
    (11, 'merge_invoices', 'Merge invoices'),
    (11, 'delete_baskets', 'Delete baskets'),
+   (12, 'suggestions_create', 'Create purchase suggestions'),
    (12, 'suggestions_manage', 'Manage purchase suggestions'),
+   (12, 'suggestions_delete', 'Delete purchase suggestions'),
    (13, 'edit_additional_contents', 'Write additional contents for the OPAC and staff interfaces (news and HTML customizations)'),
    (13, 'label_creator', 'Create printable labels and barcodes from catalog and patron data'),
    (13, 'edit_calendar', 'Define days when the library is closed'),
@@ -145,9 +147,11 @@ INSERT INTO permissions (module_bit, code, description) VALUES
    (19, 'report', 'Use report plugins'),
    (19, 'admin', 'Use administrative plugins'),
    (19, 'configure', 'Configure plugins'),
+   (20, 'create_public_lists', 'Create public lists'),
    (20, 'delete_public_lists', 'Delete public lists'),
    (20, 'edit_public_lists', 'Edit public lists'),
    (20, 'edit_public_list_contents', 'Edit public list contents'),
+   (20, 'use_public_lists', 'Use public lists'),
    (21, 'edit_templates', 'Create and update club templates'),
    (21, 'edit_clubs', 'Create and update clubs'),
    (21, 'enroll', 'Enroll patrons in clubs'),
