@@ -942,6 +942,7 @@ function _dt_add_filters(table_node, table_dt, filters_options = {}) {
         }
     } );
     _dt_add_delay_filters(table_dt, table_node);
+    table_dt.fixedHeader.adjust();
 }
 
 function _dt_add_delay(table_dt, table_node) {
@@ -1094,6 +1095,7 @@ function _dt_save_restore_state(table_settings, external_filter_nodes={}){
 
     return {
         stateSave: true,
+        stateDuration: 0,
         stateSaveCallback,
         stateLoadCallback,
         stateSaveParams,
