@@ -104,7 +104,6 @@ $(window).load(function() {
     verify_cover_images();
 });
 
-var Sticky;
 var toHighlight = {};
 var q_array;
 
@@ -130,12 +129,6 @@ $(document).ready(function() {
         $(this).toggle();
     });
 
-    Sticky = $("#searchheader");
-    Sticky.hcSticky({
-        stickTo: "main",
-        stickyClass: "floating"
-    });
-
     $("#cartsubmit").click(function(e){
         e.preventDefault();
         addMultiple();
