@@ -262,9 +262,11 @@ if ( ( $op eq 'cud-insert' ) and !$nodouble ) {
 #Attempt to delete guarantors
 my @delete_guarantor = $input->multi_param('delete_guarantor');
 if (@delete_guarantor) {
-    if ( C4::Context->preference('ChildNeedsGuarantor')
-        && scalar @guarantors - scalar @delete_guarantor == 0 )
-    {
+    my $will_remove_last =
+           ( scalar @guarantors - scalar @delete_guarantor == 0 )
+        && $newdata{'contactname'} eq q{}
+        && $newdata{'contactfirstname'} eq q{};
+    if ( C4::Context->preference('ChildNeedsGuarantor') && $will_remove_last ) {
         push @errors, 'ERROR_cannot_delete_guarantor';
     } else {
         foreach my $id (@delete_guarantor) {
@@ -908,7 +910,7 @@ if ( defined $min ) {
 }
 
 if ( C4::Context->preference('TranslateNotices') ) {
-    my $translated_languages = C4::Languages::getTranslatedLanguages( 'opac', C4::Context->preference('template') );
+    my $translated_languages = C4::Languages::getTranslatedLanguages( 'opac', C4::Context->preference('opacthemes') );
     $template->param( languages => $translated_languages );
 }
 
