@@ -64,9 +64,8 @@ use Koha::BackgroundJobs;
 use Koha::SearchEngine;
 use Koha::SearchEngine::Indexer;
 
-
-my ( $help, $batch_size );
-
+my $help;
+my $batch_size = 10;
 my $not_found_retries = {};
 my $max_retries = $ENV{MAX_RETRIES} || 10;
 
@@ -77,8 +76,6 @@ GetOptions(
 
 pod2usage(0) if $help;
 
-$batch_size //= 10;
-
 warn "Not using Elasticsearch" unless C4::Context->preference('SearchEngine') eq 'Elasticsearch';
 
 my $logger = Koha::Logger->get({ interface =>  'worker' });
@@ -118,8 +115,27 @@ while (1) {
         }
 
         my $args = try {
+            my $command      = $frame->command;
             my $body = $frame->body;
+            my $content_type = $frame->content_type;
+            if ( $command && $command eq 'MESSAGE' ) {
+                if ( $content_type && $content_type eq 'application/json' ) {
             decode_json($body); # TODO Should this be from_json? Check utf8 flag.
+                } else {
+
+                    #TODO: This is a fallback for older enqueued messages which are missing the content-type header
+                    #TODO: Please replace this decode with a die in the future once content-type is well established
+                    decode_json($body);    # TODO Should this be from_json? Check utf8 flag.
+                }
+            } elsif ( $command && $command eq 'ERROR' ) {
+
+                #Known errors:
+                #You must log in using CONNECT first
+                #"NACK" must include a valid "message-id" header
+                Koha::Logger->get( { interface => 'worker' } )
+                    ->warn( sprintf "Shutting down after receiving ERROR frame:\n%s\n", $frame->as_string );
+                exit 1;
+            }
         } catch {
             Koha::Logger->get({ interface => 'worker' })->warn(sprintf "Frame not processed - %s", $_);
             return;
@@ -171,7 +187,9 @@ while (1) {
 
     } else {
         @jobs = Koha::BackgroundJobs->search(
-            { status => 'new', queue => 'elastic_index' } )->as_list;
+            { status => 'new', queue => 'elastic_index' },
+            { rows   => $batch_size }
+        )->as_list;
         commit(@jobs);
         @jobs = ();
         sleep 10;
