@@ -36,9 +36,13 @@ my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
 $template->param (
     admin => $admin,
     errno => 403,
+    csrf_error => $ENV{'plack.middleware.Koha.CSRF'},
 );
+
 my $status = '403 Forbidden';
 if ( C4::Context->is_internal_PSGI_request() ) {
     $status = '200 OK';
 }
+#NOTE: We're not setting/updating the cookie here
+$cookie = '';
 output_with_http_headers $query, $cookie, $template->output, 'html', $status;
