@@ -52,12 +52,12 @@ use CGI qw ( -utf8 );
 use C4::Biblio qw(
     CountItemsIssued
     GetAuthorisedValueDesc
-    GetMarcControlnumber
     GetMarcFromKohaField
     GetMarcISSN
     GetMarcStructure
     TransformMarcToKoha
 );
+use C4::Record qw( marc2cites );
 use C4::Reserves qw( IsAvailableForItemLevelRequest );
 use C4::Members;
 use C4::Koha qw( GetNormalizedISBN );
@@ -92,9 +92,7 @@ my ( $template, $loggedinuser, $cookie ) = get_template_and_user(
 
 my $patron = Koha::Patrons->find($loggedinuser);
 my $biblio = Koha::Biblios->find($biblionumber);
-
-my $record = $biblio ? $biblio->metadata->record : undef;
-if ( ! $record ) {
+if ( !$biblio ) {
     print $query->redirect("/cgi-bin/koha/errors/404.pl");
     exit;
 }
@@ -135,19 +133,25 @@ unless ( $patron and $patron->category->override_hidden_items ) {
     }
 }
 
+my $metadata_extractor = $biblio->metadata_extractor;
+
 my $items = $biblio->items->filter_by_visible_in_opac({ patron => $patron });
 my $framework = $biblio ? $biblio->frameworkcode : q{};
 my $tagslib   = &GetMarcStructure( 0, $framework );
 
-my $record_processor = Koha::RecordProcessor->new({
-    filters => [ 'EmbedItems', 'ViewPolicy' ],
-    options => {
-        interface     => 'opac',
-        frameworkcode => $framework,
-        items         => [ $items->as_list ],
+my $record = $biblio
+    ? $biblio->metadata_record(
+    {
+        embed_items => 1,
+        opac        => 1,
+        patron      => $patron,
     }
-});
-$record_processor->process($record);
+    )
+    : undef;
+if ( !$record ) {
+    print $query->redirect("/cgi-bin/koha/errors/404.pl");
+    exit;
+}
 
 # get biblionumbers stored in the cart
 if(my $cart_list = $query->cookie("bib_list")){
@@ -366,12 +370,12 @@ if ( C4::Context->preference("OPACISBD") ) {
 }
 
 #Search for title in links
-my $marcflavour  = C4::Context->preference("marcflavour");
-my $dat = TransformMarcToKoha({ record => $record });
-my $isbn = GetNormalizedISBN(undef,$record,$marcflavour);
-my $marccontrolnumber   = GetMarcControlnumber ($record, $marcflavour);
-my $marcissns = GetMarcISSN( $record, $marcflavour );
-my $issn = $marcissns->[0] || '';
+my $marcflavour    = C4::Context->preference("marcflavour");
+my $dat            = TransformMarcToKoha( { record => $record } );
+my $isbn           = GetNormalizedISBN( undef, $record, $marcflavour );
+my $control_number = $metadata_extractor->get_control_number();
+my $marcissns      = GetMarcISSN( $record, $marcflavour );
+my $issn           = $marcissns->[0] || '';
 
 if (my $search_for_title = C4::Context->preference('OPACSearchForTitleIn')){
     $dat->{title} =~ s/\/+$//; # remove trailing slash
@@ -384,7 +388,7 @@ if (my $search_for_title = C4::Context->preference('OPACSearchForTitleIn')){
             AUTHOR        => $dat->{author},
             ISBN          => $isbn,
             ISSN          => $issn,
-            CONTROLNUMBER => $marccontrolnumber,
+            CONTROLNUMBER => $control_number,
             BIBLIONUMBER  => $biblionumber,
             OCLC_NO       => $oclc_no,
         }
@@ -412,4 +416,7 @@ $template->param(
     borrowernumber      => $loggedinuser,
 );
 
+# Cites
+$template->param( cites => C4::Record::marc2cites($record) );
+
 output_html_with_http_headers $query, $cookie, $template->output;
