@@ -38,13 +38,13 @@ use C4::Output qw( parametrized_url output_html_with_http_headers );
 use C4::Biblio qw(
     CountItemsIssued
     GetBiblioData
-    GetMarcControlnumber
     GetMarcISBN
     GetMarcISSN
     GetMarcSeries
     GetMarcSubjects
     GetMarcUrls
 );
+use C4::Record qw( marc2cites );
 use C4::Tags qw( get_tags );
 use C4::XISBN qw( get_xisbns );
 use C4::External::Amazon qw( get_amazon_tld );
@@ -139,6 +139,8 @@ if ( C4::Context->preference('OpacSuppression') ) {
     }
 }
 
+my $metadata_extractor = $biblio->metadata_extractor;
+
 my $items = $biblio->items->search_ordered;
 if ($specific_item) {
     $items = $items->search( { itemnumber => scalar $query->param('itemnumber') } );
@@ -666,6 +668,8 @@ my $holdable_items = $biblio->items->filter_by_for_hold->count;
 my $can_holds_be_placed = $patron ? 0 : $holdable_items;
 
 my ( $itemloop_has_images, $otheritemloop_has_images );
+my $item_level_holds;
+my $item_checkouts;
 if ( not $viewallitems and $items->count > $max_items_to_display ) {
     $template->param(
         too_many_items => 1,
@@ -677,6 +681,7 @@ else {
     while ( my $item = $items->next ) {
         my $item_info = $item->unblessed;
         $item_info->{holds_count} = $item_reserves{ $item->itemnumber };
+        if ( $item_info->{holds_count} && $item_info->{holds_count} > 0 ) { $item_level_holds = 1; }
         $item_info->{priority}    = $priority{ $item->itemnumber };
 
         # Get opac_info from Additional contents for home and holding library
@@ -717,9 +722,11 @@ else {
         $item_info->{'description'} =
           $itemtypes->{ $itemtype->itemtype }->{translated_description};
 
+        $item_info->{checkout} = $item->checkout;
+        if ( $item_info->{checkout} && $item_info->{checkout} > 0 ) { $item_checkouts = 1; }
+
         foreach my $field (
-            qw(ccode materials enumchron copynumber itemnotes location_description uri)
-          )
+            qw(ccode materials enumchron copynumber itemnotes location_description uri barcode itemcallnumber))
         {
             $itemfields{$field} = 1 if $item_info->{$field};
         }
@@ -731,7 +738,6 @@ else {
             $item_info->{serial} = $serial if $serial;
         }
 
-        $item_info->{checkout} = $item->checkout;
         $item_info->{object} = $item;
 
 
@@ -768,6 +774,8 @@ else {
 }
 
 $template->param(
+    item_checkouts           => $item_checkouts,
+    item_level_holds         => $item_level_holds,
     ReservableItems          => $can_holds_be_placed,
     itemloop_has_images      => $itemloop_has_images,
     otheritemloop_has_images => $otheritemloop_has_images,
@@ -794,17 +802,19 @@ if( C4::Context->preference('ArticleRequests') ) {
     $template->param( artreqpossible => $artreqpossible );
 }
 
-    $template->param(
-                     MARCNOTES               => $marcnotesarray,
-                     itemdata_ccode          => $itemfields{ccode},
-                     itemdata_materials      => $itemfields{materials},
-                     itemdata_enumchron      => $itemfields{enumchron},
-                     itemdata_uri            => $itemfields{uri},
-                     itemdata_copynumber     => $itemfields{copynumber},
-                     itemdata_itemnotes      => $itemfields{itemnotes},
-                     itemdata_location       => $itemfields{location_description},
-                     OpacStarRatings         => C4::Context->preference("OpacStarRatings"),
-    );
+$template->param(
+    MARCNOTES               => $marcnotesarray,
+    itemdata_ccode          => $itemfields{ccode},
+    itemdata_materials      => $itemfields{materials},
+    itemdata_enumchron      => $itemfields{enumchron},
+    itemdata_uri            => $itemfields{uri},
+    itemdata_copynumber     => $itemfields{copynumber},
+    itemdata_itemnotes      => $itemfields{itemnotes},
+    itemdata_location       => $itemfields{location_description},
+    itemdata_barcode        => $itemfields{barcode},
+    itemdata_itemcallnumber => $itemfields{itemcallnumber},
+    OpacStarRatings         => C4::Context->preference("OpacStarRatings"),
+);
 
 if (C4::Context->preference("AlternateHoldingsField") && $items->count == 0) {
     my $fieldspec = C4::Context->preference("AlternateHoldingsField");
@@ -1154,9 +1164,9 @@ if ( C4::Context->preference('OpacStarRatings') !~ /disable/ ) {
 }
 
 #Search for title in links
-my $marccontrolnumber   = GetMarcControlnumber ($record, $marcflavour);
-my $marcissns = GetMarcISSN ( $record, $marcflavour );
-my $issn = $marcissns->[0] || '';
+my $control_number = $metadata_extractor->get_control_number();
+my $marcissns      = GetMarcISSN( $record, $marcflavour );
+my $issn           = $marcissns->[0] || '';
 
 if (my $search_for_title = C4::Context->preference('OPACSearchForTitleIn')){
     $dat->{title} =~ s/\/+$//; # remove trailing slash
@@ -1169,7 +1179,7 @@ if (my $search_for_title = C4::Context->preference('OPACSearchForTitleIn')){
             AUTHOR        => $dat->{author},
             ISBN          => $isbn,
             ISSN          => $issn,
-            CONTROLNUMBER => $marccontrolnumber,
+            CONTROLNUMBER => $control_number,
             BIBLIONUMBER  => $biblionumber,
             OCLC_NO       => $oclc_no,
         }
@@ -1247,4 +1257,7 @@ if ( C4::Context->preference('OPACAuthorIdentifiersAndInformation') ) {
     $template->param( author_information => \@author_information );
 }
 
+# Cites
+$template->param( cites => C4::Record::marc2cites($record) );
+
 output_html_with_http_headers $query, $cookie, $template->output;
