@@ -313,7 +313,7 @@ elsif ( $op eq 'cud-choose_type' ) {
         'build3' => 1,
         'area'   => $area,
         'type'   => $type,
-        columns  => get_columns($area,$input),
+        columns  => get_columns($area),
         'cache_expiry' => scalar $input->param('cache_expiry'),
         'public' => scalar $input->param('public'),
     );
@@ -630,7 +630,7 @@ elsif ($op eq 'export'){
         $reportname ? "$report_id-$reportname-reportresults.$format" : "$report_id-reportresults.$format";
     my $scrubber = C4::Scrubber->new();
 
-    ($sql, undef) = $report->prep_report( \@param_names, \@sql_params );
+    ($sql, undef) = $report->prep_report( \@param_names, \@sql_params, { export => 1 } );
     my ( $sth, $q_errors ) = execute_query( { sql => $sql, report_id => $report_id } );
     unless ($q_errors and @$q_errors) {
         my ( $type, $content );
@@ -645,6 +645,10 @@ elsif ($op eq 'export'){
             if ( $format eq 'csv' ) {
                 my $delimiter = C4::Context->csv_delimiter;
                 $type = 'application/csv';
+
+                # Add BOM for UTF-8 encoded CSV
+                $content .= "\xEF\xBB\xBF";
+
                 my $csv = Text::CSV::Encoded->new({ encoding_out => 'UTF-8', sep_char => $delimiter, formula => 'empty' });
                 $csv or die "Text::CSV::Encoded->new({binary => 1}) FAILED: " . Text::CSV::Encoded->error_diag();
                 if ( $csv->combine( header_cell_values($sth) ) ) {
@@ -662,7 +666,7 @@ elsif ($op eq 'export'){
                     }
                 }
             }
-            elsif ( $format eq 'ods' ) {
+            elsif ( $format eq 'ods' && C4::Context->preference('ReportsExportFormatODS') ) {
                 $type = 'application/vnd.oasis.opendocument.spreadsheet';
                 my $ods_fh = File::Temp->new( UNLINK => 0 );
                 my $ods_filepath = $ods_fh->filename;
@@ -689,7 +693,11 @@ elsif ($op eq 'export'){
                 # Output
                 binmode(STDOUT);
                 open $ods_fh, '<', $ods_filepath;
-                $content .= $_ while <$ods_fh>;
+                print $input->header(
+                    -type       => $type,
+                    -attachment => $reportfilename
+                );
+                print $_ while <$ods_fh>;
                 unlink $ods_filepath;
             }
             elsif ( $format eq 'template' ) {
@@ -713,11 +721,14 @@ elsif ($op eq 'export'){
                 );
             }
         }
-        print $input->header(
-            -type => $type,
-            -attachment=> $reportfilename
-        );
-        print $content;
+
+        unless ( $format eq 'ods' ) {
+            print $input->header(
+                -type       => $type,
+                -attachment => $reportfilename
+            );
+            print $content;
+        }
 
         foreach my $err (@$q_errors, @errors) {
             print "# ERROR: " . (map {$_ . ": " . $err->{$_}} keys %$err) . "\n";
@@ -945,6 +956,7 @@ if ($op eq 'run'){
                             'auth_val_errors'  => \@authval_errors,
                             'enter_params' => 1,
                             'id'           => $report_id,
+                            'template_id'  => $template_id,
                             );
         } else {
             my ($sql,$header_types) = $report->prep_report( \@param_names, \@sql_params );
