@@ -27,7 +27,7 @@ describe("Agreement CRUD operations", () => {
         });
         cy.visit("/cgi-bin/koha/erm/erm.pl");
         cy.get("#navmenulist").contains("Agreements").click();
-        cy.get("main div[class='dialog alert']").contains(
+        cy.get("main div[class='alert alert-warning']").contains(
             "Something went wrong: Error: Internal Server Error"
         );
 
@@ -299,7 +299,7 @@ describe("Agreement CRUD operations", () => {
             statusCode: 500,
         });
         cy.get("#agreements_add").contains("Submit").click();
-        cy.get("main div[class='dialog alert']").contains(
+        cy.get("main div[class='alert alert-warning']").contains(
             "Something went wrong: Error: Internal Server Error"
         );
 
@@ -309,7 +309,7 @@ describe("Agreement CRUD operations", () => {
             body: agreement,
         });
         cy.get("#agreements_add").contains("Submit").click();
-        cy.get("main div[class='dialog message']").contains(
+        cy.get("main div[class='alert alert-info']").contains(
             "Agreement created"
         );
 
@@ -503,7 +503,7 @@ describe("Agreement CRUD operations", () => {
         cy.get("#agreements_add").contains("Submit").click();
         cy.get("main div[class='modal_centered']").contains("Submitting...");
         cy.wait(1000);
-        cy.get("main div[class='dialog alert']").contains(
+        cy.get("main div[class='alert alert-warning']").contains(
             "Something went wrong: Error: Internal Server Error"
         );
 
@@ -513,7 +513,7 @@ describe("Agreement CRUD operations", () => {
             body: agreement,
         });
         cy.get("#agreements_add").contains("Submit").click();
-        cy.get("main div[class='dialog message']").contains(
+        cy.get("main div[class='alert alert-info']").contains(
             "Agreement updated"
         );
     });
@@ -568,14 +568,15 @@ describe("Agreement CRUD operations", () => {
                 "X-Base-Total-Count": "1",
                 "X-Total-Count": "1",
             },
-        });
+        }).as("get-agreements");
         cy.intercept("GET", "/api/v1/erm/agreements/*", agreement);
         cy.visit("/cgi-bin/koha/erm/agreements");
+        cy.wait("@get-agreements");
 
         cy.get("#agreements_list table tbody tr:first")
             .contains("Delete")
             .click();
-        cy.get(".dialog.alert.confirmation h1").contains(
+        cy.get(".alert-warning.confirmation h1").contains(
             "remove this agreement"
         );
         cy.contains(agreement.name);
@@ -585,7 +586,7 @@ describe("Agreement CRUD operations", () => {
             statusCode: 500,
         });
         cy.contains("Yes, delete").click();
-        cy.get("main div[class='dialog alert']").contains(
+        cy.get("main div[class='alert alert-warning']").contains(
             "Something went wrong: Error: Internal Server Error"
         );
 
@@ -597,24 +598,18 @@ describe("Agreement CRUD operations", () => {
         cy.get("#agreements_list table tbody tr:first")
             .contains("Delete")
             .click();
-        cy.get(".dialog.alert.confirmation h1").contains(
+        cy.get(".alert-warning.confirmation h1").contains(
             "remove this agreement"
         );
         cy.contains("Yes, delete").click();
-        cy.get("main div[class='dialog message']")
+        cy.get("main div[class='alert alert-info']")
             .contains("Agreement")
             .contains("deleted");
 
         // Delete from show
         // Click the "name" link from the list
-        cy.intercept("GET", "/api/v1/erm/agreements*", {
-            statusCode: 200,
-            body: agreements,
-            headers: {
-                "X-Base-Total-Count": "1",
-                "X-Total-Count": "1",
-            },
-        });
+        cy.visit("/cgi-bin/koha/erm/agreements");
+        cy.wait("@get-agreements");
         cy.intercept("GET", "/api/v1/erm/agreements/*", agreement).as(
             "get-agreement"
         );
@@ -628,13 +623,12 @@ describe("Agreement CRUD operations", () => {
         );
         name_link.click();
         cy.wait("@get-agreement");
-        cy.wait(500); // Cypress is too fast! Vue hasn't populated the form yet!
         cy.get("#agreements_show h2").contains(
             "Agreement #" + agreement.agreement_id
         );
 
-        cy.get("#agreements_show .action_links .fa-trash").click();
-        cy.get(".dialog.alert.confirmation h1").contains(
+        cy.get("#agreements_show #toolbar").contains("Delete").click();
+        cy.get(".alert-warning.confirmation h1").contains(
             "remove this agreement"
         );
         cy.contains("Yes, delete").click();
