@@ -29,7 +29,7 @@ describe("Data provider CRUD operations", () => {
         });
         cy.visit("/cgi-bin/koha/erm/erm.pl");
         cy.get("#navmenulist").contains("Data providers").click();
-        cy.get("main div[class='dialog alert']").contains(
+        cy.get("main div[class='alert alert-warning']").contains(
             /Something went wrong/
         );
 
@@ -137,7 +137,7 @@ describe("Data provider CRUD operations", () => {
         //     error: "Something went wrong",
         // });
         // cy.get("#data_providers_add").contains("Submit").click();
-        // cy.get("main div[class='dialog alert']").contains(
+        // cy.get("main div[class='alert alert-warning']").contains(
         //     "Something went wrong: Error: Internal Server Error"
         // );
 
@@ -147,7 +147,7 @@ describe("Data provider CRUD operations", () => {
             body: dataProvider,
         });
         cy.get("#data_providers_add").contains("Submit").click();
-        cy.get("main div[class='dialog message']").contains(
+        cy.get("main div[class='alert alert-info']").contains(
             "Data provider created"
         );
 
@@ -245,7 +245,7 @@ describe("Data provider CRUD operations", () => {
         //     error: "Something went wrong",
         // });
         // cy.get("#data_providers_add").contains("Submit").click();
-        // cy.get("main div[class='dialog alert']").contains(
+        // cy.get("main div[class='alert alert-warning']").contains(
         //     "Something went wrong: Error: Internal Server Error"
         // );
         // Submit the form, success!
@@ -254,7 +254,7 @@ describe("Data provider CRUD operations", () => {
             body: dataProvider,
         });
         cy.get("#data_providers_add").contains("Submit").click();
-        cy.get("main div[class='dialog message']").contains(
+        cy.get("main div[class='alert alert-info']").contains(
             "Data provider updated"
         );
     });
@@ -319,7 +319,7 @@ describe("Data provider CRUD operations", () => {
         cy.get("#usage_data_providers_list table tbody tr:first")
             .contains("Delete")
             .click();
-        cy.get(".dialog.alert.confirmation h1").contains(
+        cy.get(".alert-warning.confirmation h1").contains(
             "remove this data provider"
         );
         cy.contains(dataProvider.name);
@@ -330,7 +330,7 @@ describe("Data provider CRUD operations", () => {
         //     error: "Something went wrong",
         // });
         // cy.contains("Yes, delete").click();
-        // cy.get("main div[class='dialog alert']").contains(
+        // cy.get("main div[class='alert alert-warning']").contains(
         //     "Something went wrong: Error: Internal Server Error"
         // );
 
@@ -342,11 +342,11 @@ describe("Data provider CRUD operations", () => {
         // cy.get("#usage_data_providers_list table tbody tr:first")
         //     .contains("Delete")
         //     .click();
-        // cy.get(".dialog.alert.confirmation h1").contains(
+        // cy.get(".alert-warning.confirmation h1").contains(
         //     "remove this data provider"
         // );
         cy.contains("Yes, delete").click();
-        cy.get("main div[class='dialog message']")
+        cy.get("main div[class='alert alert-info']")
             .contains("Data provider")
             .contains("deleted");
 
@@ -383,8 +383,10 @@ describe("Data provider CRUD operations", () => {
             "Data provider #" + dataProvider.erm_usage_data_provider_id
         );
 
-        cy.get("#usage_data_providers_show .action_links .fa-trash").click();
-        cy.get(".dialog.alert.confirmation h1").contains(
+        cy.get("#usage_data_providers_show #toolbar")
+            .contains("Delete")
+            .click();
+        cy.get(".alert-warning.confirmation h1").contains(
             "remove this data provider"
         );
         cy.contains("Yes, delete").click();
@@ -589,7 +591,7 @@ describe("Data provider tab options", () => {
 
         // We'll test using titles but the component is the same for all four data types
         cy.get("#usage_data_providerstabs").contains("Titles").click();
-        cy.get("main div[class='dialog message']").should(
+        cy.get("main div[class='alert alert-info']").should(
             "have.text",
             "No title data has been harvested for this provider"
         );
@@ -636,7 +638,7 @@ describe("Data provider tab options", () => {
 
         cy.get("#files > form > fieldset > input[type=submit]").click();
 
-        cy.get("main div[class='dialog message']").should(
+        cy.get("main div[class='alert alert-info']").should(
             "have.text",
             "Job for uploaded file has been queued. Check job progress."
         );
@@ -652,7 +654,7 @@ describe("Data provider tab options", () => {
             },
         });
         cy.get("#usage_data_providerstabs").contains("Import logs").click();
-        cy.get("main div[class='dialog message']").should(
+        cy.get("main div[class='alert alert-info']").should(
             "have.text",
             "There are no import logs defined"
         );
@@ -680,6 +682,11 @@ describe("Data provider tab options", () => {
 
         cy.get("#usage_data_providerstabs").contains("Import logs").click();
         cy.get("#counter_logs_list").contains("Showing 1 to 1 of 1 entries");
+
+        // Check 'Imported by' name
+        cy.get("#counter_logs_list table tbody tr:first td")
+            .eq(2)
+            .contains("koha");
     });
 });
 
@@ -712,7 +719,7 @@ describe("Data providers action buttons", () => {
         cy.get("#usage_data_providers_list table tbody tr:first")
             .contains("Run now")
             .click();
-        cy.get(".modal_centered p").contains(dataProvider.name);
+        cy.get(".modal.confirmation p").contains(dataProvider.name);
 
         cy.intercept(
             "POST",
@@ -741,7 +748,7 @@ describe("Data providers action buttons", () => {
                 cy.get(".dayContainer").contains(new RegExp("^1$")).click();
             });
         cy.get("#accept_modal").click();
-        cy.get("main div[class='dialog message']").should(
+        cy.get("main div[class='alert alert-info']").should(
             "have.text",
             "Job for report type TR_J1 has been queued. Check job progress."
         );
@@ -778,7 +785,7 @@ describe("Data providers action buttons", () => {
             .contains("Test")
             .click();
         cy.wait("@test-connection");
-        cy.get("main div[class='dialog message']").should(
+        cy.get("main div[class='alert alert-info']").should(
             "have.text",
             "Harvester connection was successful for usage data provider " +
                 dataProvider.name
