@@ -151,6 +151,11 @@ sub after_hold_create {
     Koha::Exception->throw("after_hold_create called with parameter " . ref($param) );
 }
 
+sub before_send_messages {
+    my ( $self, $param ) = @_;
+    Koha::Exception->throw("before_send_messages called");
+}
+
 sub before_biblio_action {
     my ( $self, $params ) = @_;
 
@@ -452,8 +457,29 @@ sub auth_client_get_user {
     return;
 }
 
+sub overwrite_calc_fine {
+    my ( $self, $params ) = @_;
+
+    warn "itemnumber:" . $params->{itemnumber};
+    warn "borrowernumber:" . $params->{borrowernumber};
+    warn "branchcode:" . $params->{branchcode};
+    warn "categorycode:" . $params->{categorycode};
+    warn "due_date_type:" . ref( $params->{due_date} );
+    warn "end_date_type:" . ref( $params->{end_date} );
+
+    return [ 1, 2, 3 ];
+}
+
 sub _private_sub {
     return "";
 }
 
+sub elasticsearch_to_document {
+    my ( $self, $params ) = @_;
+    my $record = $params->{record};
+    my $doc    = $params->{document};
+
+    Koha::Exception->throw( "elasticsearch_to_document ref record: " . ref($record) . " - ref document: " . ref($doc) );
+}
+
 1;
