@@ -70,7 +70,7 @@ if ( $to_address && $op eq 'cud-send' ) {
     while ( my $content = $contents->next ) {
         push @biblionumbers, $content->biblionumber;
         my $biblio = Koha::Biblios->find( $content->biblionumber );
-        $iso2709 .= $biblio->metadata->record->as_usmarc();
+        $iso2709 .= $biblio->metadata_record()->as_usmarc();
     }
 
     if ( !defined $iso2709 ) {
@@ -90,7 +90,7 @@ if ( $to_address && $op eq 'cud-send' ) {
         );
 
         my $letter = C4::Letters::GetPreparedLetter(
-            module      => 'catalogue',
+            module      => 'lists',
             letter_code => 'LIST',
             lang        => $patron->lang,
             tables      => {
